/** 
 * 
 * Copyright 2005 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/

package org.servicemix.components.http;

import org.servicemix.components.util.ComponentSupport;
import org.servicemix.jbi.jaxp.SourceTransformer;

import javax.jbi.JBIException;
import javax.jbi.messaging.ExchangeStatus;
import javax.jbi.messaging.InOut;
import javax.jbi.messaging.MessageExchangeFactory;
import javax.jbi.messaging.NormalizedMessage;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.xml.transform.TransformerException;
import java.io.IOException;
import java.io.PrintWriter;

/**
 * @version $Revision: 1.1 $
 */
public class HttpBinding extends ComponentSupport {
    // TODO is the correct?
    protected static final int BAD_REQUEST_STATUS_CODE = HttpServletResponse.SC_BAD_GATEWAY;

    private HttpMarshaler marshaler = new HttpMarshaler();

    /**
     * @param request
     * @param response
     * @throws ServletException
     * @throws IOException
     * @throws JBIException
     */
    public void process(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException,
            JBIException {
        //response.setContentType("application/soap+xml");
        MessageExchangeFactory factory = getExchangeFactory();
        InOut messageExchange = factory.createInOutExchange();
        NormalizedMessage inMessage = messageExchange.createMessage();
        try {
            marshaler.toNMS(inMessage, request);
            messageExchange.setInMessage(inMessage);
            boolean result = getDeliveryChannel().sendSync(messageExchange);
            if (result) {
                marshaler.toResponse(messageExchange.getOutMessage(), response);
            }
        }
        catch (IOException e) {
            fail(messageExchange, e);
            outputException(response, e);
        }
        catch (TransformerException e) {
            fail(messageExchange, e);
            outputException(response, e);
        }
    }

    protected void outputException(HttpServletResponse response, Exception e) throws IOException {
        response.setStatus(BAD_REQUEST_STATUS_CODE);
        PrintWriter writer = response.getWriter();
        writer.println("Request failed with error: " + e);
        e.printStackTrace(writer);
    }
}
