/** 
 * 
 * Copyright 2005 LogicBlaze, Inc. http://www.logicblaze.com
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.servicemix.components.jms;

import org.springframework.beans.factory.DisposableBean;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.jms.core.JmsTemplate;
import org.springframework.jms.core.SessionCallback;

import javax.jms.Destination;
import javax.jms.JMSException;
import javax.jms.MessageConsumer;
import javax.jms.Session;

/**
 * A component which uses a {@link JmsTemplate} to consume messages from a destination.
 *
 * @version $Revision: 1.1 $
 */
public class JmsReceiverComponent extends JmsInBinding implements InitializingBean, DisposableBean {
    private JmsTemplate template;
    private String selector;
    private MessageConsumer consumer;

    public void afterPropertiesSet() throws Exception {
        if (template == null) {
            throw new IllegalArgumentException("Must have a template set");
        }
        template.execute(new SessionCallback() {
            public Object doInJms(Session session) throws JMSException {
                Destination defaultDestination = template.getDefaultDestination();
                if (defaultDestination == null) {
                    defaultDestination = template.getDestinationResolver().resolveDestinationName(session, template.getDefaultDestinationName(), template.isPubSubDomain());
                }
                consumer = session.createConsumer(defaultDestination, selector);
                return null;
            }
        }, true);
        consumer.setMessageListener(this);
    }

    public void destroy() throws Exception {
        if (consumer != null) {
            consumer.close();
        }
    }

    public JmsTemplate getTemplate() {
        return template;
    }

    public void setTemplate(JmsTemplate template) {
        this.template = template;
    }

    public String getSelector() {
        return selector;
    }

    public void setSelector(String selector) {
        this.selector = selector;
    }
}

