/** 
 * 
 * Copyright 2005 LogicBlaze, Inc. http://www.logicblaze.com
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.servicemix.jbi.component;

import org.servicemix.jbi.deployment.ClassPath;
import org.servicemix.jbi.deployment.Component;
import org.servicemix.jbi.deployment.Descriptor;
import org.servicemix.jbi.deployment.Identification;
import org.servicemix.jbi.deployment.InstallationDescriptorExtension;
import org.w3c.dom.DocumentFragment;

import javax.jbi.component.ComponentContext;
import javax.jbi.component.InstallationContext;
import java.util.List;

/**
 * The default implementation of {@link InstallationContext}
 *
 * @version $Revision: 1.2 $
 */
public class InstallationContextImpl implements InstallationContext {

    private Descriptor descriptor;
    private ComponentContext context;
    private String installRoot;
    private boolean install;

    public InstallationContextImpl(Descriptor descriptor) {
        this.descriptor = descriptor;
    }

    public String getComponentClassName() {
        Component component = descriptor.getComponent();
        if (component != null) {
            return component.getComponentClassName();
        }
        return null;
    }

    public List getClassPathElements() {
        Component component = descriptor.getComponent();
        if (component != null) {
            ClassPath classPath = component.getComponentClassPath();
            if (classPath != null) {
                return classPath.getPathList();
            }
        }
        return null;
    }

    public String getComponentName() {
        Component component = descriptor.getComponent();
        if (component != null) {
            Identification identification = component.getIdentification();
            if (identification != null) {
                return identification.getName();
            }
        }
        return null;
    }

    public ComponentContext getContext() {
        return context;
    }

    public String getInstallRoot() {
        return installRoot;
    }

    public DocumentFragment getInstallationDescriptorExtension() {
        Component component = descriptor.getComponent();
        if (component != null) {
            InstallationDescriptorExtension descriptorExtension = component.getDescriptorExtension();
            if (descriptorExtension != null) {
                return descriptorExtension.getDescriptorExtension();
            }
        }
        return null;
    }

    public boolean isInstall() {
        return install;
    }

    public void setClassPathElements(List classPathElements) {
        Component component = descriptor.getComponent();
        if (component != null) {
            ClassPath classPath = component.getComponentClassPath();
            if (classPath != null) {
                classPath.setPathList(classPathElements);
            }
        }
    }

    public void setContext(ComponentContext context) {
        this.context = context;
    }

    public void setDescriptor(Descriptor descriptor) {
        this.descriptor = descriptor;
    }

    public void setInstall(boolean install) {
        this.install = install;
    }

    public void setInstallRoot(String installRoot) {
        this.installRoot = installRoot;
    }
}
