/**
 * 
 * Copyright 2005 LogicBlaze, Inc. http://www.logicblaze.com
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.servicemix.components.email;

import org.servicemix.TestSupport;
import org.servicemix.jbi.resolver.ServiceNameEndpointResolver;
import org.springframework.context.support.AbstractXmlApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;
import org.springframework.mail.SimpleMailMessage;
import org.w3c.dom.Node;

import javax.xml.namespace.QName;
import javax.xml.transform.Source;
import javax.jbi.messaging.InOut;
import javax.jbi.messaging.NormalizedMessage;
import javax.jbi.messaging.InOnly;
import javax.mail.internet.MimeMessage;
import java.util.Date;
import java.util.List;

/**
 * @version $Revision: 1.1 $
 */
public class SimpleMailTest extends TestSupport {

    public void testUsingXPathExpressionsInSimpleEmail() throws Exception {

        // START SNIPPET: xpathSimple
        QName xpathSender = new QName("http://servicemix.org/cheese/", "simpleMailSenderWithExpressions");
        ServiceNameEndpointResolver resolver = new ServiceNameEndpointResolver(xpathSender);

        InOnly exchange = client.createInOnlyExchange(resolver);

        Source source = getSourceFromClassPath("request.xml");
        exchange.getInMessage().setContent(source);

        client.done(exchange);
        // END SNIPPET: xpathSimple

        // lest find the test sender
        StubJavaMailSender sender = (StubJavaMailSender) getBean("javaMailSender");
        sender.assertMessagesReceived(1);

        List messages = sender.getMessages();
        assertEquals("message size: " + messages, 1, messages.size());

        SimpleMailMessage message = (SimpleMailMessage) messages.get(0);

        System.out.println("Created message: " + message);

        assertEquals("text", "Hello there James how are you today?", message.getText());
        assertEquals("from", "james@nowhere.com", message.getFrom());
    }

    public void testUsingPropertyExpressionsInSimpleEmail() throws Exception {
        // START SNIPPET: xpathSimple
        QName xpathSender = new QName("http://servicemix.org/cheese/", "simpleMailSenderWithPropertyExpressions");
        ServiceNameEndpointResolver resolver = new ServiceNameEndpointResolver(xpathSender);

        InOnly exchange = client.createInOnlyExchange(resolver);
        NormalizedMessage message = exchange.getInMessage();

        message.setProperty("to", "scm@servicemix.org");
        message.setProperty("from", "junit@servicemix.org");
        message.setProperty("text", "Hi from test case: " + getName() + " running at: " + new Date());

        client.done(exchange);
        // END SNIPPET: xpathSimple

        // lest find the test sender
        StubJavaMailSender sender = (StubJavaMailSender) getBean("javaMailSender");
        sender.assertMessagesReceived(1);

        List messages = sender.getMessages();

        assertEquals("message size: " + messages, 1, messages.size());

        SimpleMailMessage mailMessage = (SimpleMailMessage) messages.get(0);

        System.out.println("Created message: " + mailMessage);

        assertEquals("subject", "Subject came from expression", mailMessage.getSubject());
        assertEquals("from", "junit@servicemix.org", mailMessage.getFrom());
    }

    protected AbstractXmlApplicationContext createBeanFactory() {
        return new ClassPathXmlApplicationContext("org/servicemix/components/email/simpleMail.xml");
    }
}
