/** 
 * 
 * Copyright 2005 LogicBlaze, Inc. http://www.logicblaze.com
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.servicemix.components.wsif;

import org.servicemix.TestSupport;
import org.servicemix.jbi.resolver.ServiceNameEndpointResolver;
import org.springframework.context.support.AbstractXmlApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;
import org.w3c.dom.Node;

import javax.xml.namespace.QName;
import javax.xml.transform.Source;
import javax.jbi.messaging.InOut;
import javax.jbi.messaging.NormalizedMessage;

/**
 * @version $Revision: 1.2 $
 */
public class WsifTest extends TestSupport {
    QName serviceName = new QName("http://servicemix.org/cheese/", "checkAvailability");

    public void testUsingXMLMessaging() throws Exception {
        String file = "request.xml";

        Object answer = requestServiceWithFileRequest(serviceName, file);

        Node node = null;
        if (answer instanceof Node) {
            node = (Node) answer;
        }
        else {
            assertTrue("Shoud return a Source instance: " + answer, answer instanceof Source);
            node = transformer.toDOMNode((Source) answer);
        }

        assertNotNull("Should have found a non-null node!", node);
        System.out.println(transformer.toString(node));

        String text = textValueOfXPath(node, "/*/*[local-name()='part']").trim();

        System.out.println("Found value: " + text);

        assertTrue("price text should not be empty", text.length() > 0);

    }

    public void testUsingWSIFStyleJBI() throws Exception {

        // START SNIPPET: wsif
        InOut exchange = client.createInOutExchange();

        exchange.getInMessage().setProperty("zipCode", "10505");
        client.sendSync(exchange);

        NormalizedMessage out = exchange.getOutMessage();
        String result = (String) out.getProperty("result");

        System.out.println("Found value: " + result);
        // END SNIPPET: wsif

        assertEquals("should have no fault", null, exchange.getFault());
        assertEquals("should have no error", null, exchange.getError());
        assertNotNull("must have an output message!", out);

        assertTrue("price text should not be empty", result.length() > 0);

    }

    protected AbstractXmlApplicationContext createBeanFactory() {
        return new ClassPathXmlApplicationContext("org/servicemix/components/wsif/example.xml");
    }
}
